import type { CreateScan } from '../models/CreateScan';
import type { CreateTrackScan } from '../models/CreateTrackScan';
import type { ResponseEmpty } from '../models/ResponseEmpty';
import type { ResponseScan } from '../models/ResponseScan';
import type { ResponseTrackScan } from '../models/ResponseTrackScan';
import type { UpdateScan } from '../models/UpdateScan';
import type { UpdateTrackScan } from '../models/UpdateTrackScan';
export declare class ScanService {
    /**
     * Get all
     * Lists all scans (normal or track) from all runners. <br> This includes the scan's runner's distance ran.
     * @returns any
     * @throws ApiError
     */
    static scanControllerGetAll(): Promise<(Array<ResponseScan> | Array<ResponseTrackScan>)>;
    /**
     * Post
     * Create a new scan (not track scan - use /scans/trackscans instead). <br> Please rmemember to provide the scan's runner's id and distance.
     * @param requestBody CreateScan
     * @returns ResponseScan
     * @throws ApiError
     */
    static scanControllerPost(requestBody?: CreateScan): Promise<ResponseScan>;
    /**
     * Get one
     * Lists all information about the scan whose id got provided. This includes the scan's runner's distance ran.
     * @param id
     * @returns any
     * @throws ApiError
     */
    static scanControllerGetOne(id: number): Promise<(ResponseScan | ResponseTrackScan)>;
    /**
     * Put
     * Update the scan (not track scan use /scans/trackscans/:id instead) whose id you provided. <br> Please remember that ids can't be changed and distances must be positive.
     * @param id
     * @param requestBody UpdateScan
     * @returns ResponseScan
     * @throws ApiError
     */
    static scanControllerPut(id: number, requestBody?: UpdateScan): Promise<ResponseScan>;
    /**
     * Remove
     * Delete the scan whose id you provided. <br> If no scan with this id exists it will just return 204(no content).
     * @param id
     * @param force
     * @returns ResponseScan
     * @returns ResponseEmpty
     * @throws ApiError
     */
    static scanControllerRemove(id: number, force?: boolean): Promise<ResponseScan | ResponseEmpty>;
    /**
     * Post track scans
     * Create a new track scan (for "normal" scans use /scans instead). <br> Please remember that to provide the scan's card's station's id.
     * @param requestBody CreateTrackScan
     * @returns ResponseTrackScan
     * @throws ApiError
     */
    static scanControllerPostTrackScans(requestBody?: CreateTrackScan): Promise<ResponseTrackScan>;
    /**
     * Put track scan
     * Update the track scan (not "normal" scan use /scans/trackscans/:id instead) whose id you provided. <br> Please remember that only the validity, runner and track can be changed.
     * @param id
     * @param requestBody UpdateTrackScan
     * @returns ResponseTrackScan
     * @throws ApiError
     */
    static scanControllerPutTrackScan(id: number, requestBody?: UpdateTrackScan): Promise<ResponseTrackScan>;
}
